@@ -1,10 +1,17 @@
-from notecoin.huobi.constant import (AccountType, OrderSide, OrderSource,
-                                     OrderState, OrderType)
-from notecoin.huobi.service.trade import (TradeService, TRadeServiceSocket,
-                                          TRadeServiceSocketSub)
+import time
+
+from notecoin.huobi.connection import (RestApiSyncClient, SubscribeClient,
+                                       WebSocketReqClient)
+from notecoin.huobi.constant import (AccountType, HttpMethod, OrderSide,
+                                     OrderSource, OrderState, OrderType,
+                                     TransferFuturesPro)
 from notecoin.huobi.utils import (check_currency, check_list, check_range,
                                   check_should_not_none, check_symbol,
-                                  check_symbol_list, format_date)
+                                  check_symbol_list, format_date,
+                                  orders_update_channel,
+                                  request_order_detail_channel,
+                                  request_order_list_channel,
+                                  trade_clearing_channel)
 
 
 class TradeClient(object):
@@ -19,9 +26,9 @@ class TradeClient(object):
             init_log: to init logger
         """
         self.__kwargs = kwargs
-        self.trade_client = TradeService(*args, **kwargs)
-        self.trade_client_socket = TRadeServiceSocket(*args, **kwargs)
-        self.trade_client_socket_sub = TRadeServiceSocketSub(*args, **kwargs)
+        self.trade_client = RestApiSyncClient(*args, **kwargs)
+        self.trade_client_socket = WebSocketReqClient(*args, **kwargs)
+        self.trade_client_socket_sub = SubscribeClient(*args, **kwargs)
 
     def get_fee_rate(self, symbols: str) -> list:
         """
@@ -34,12 +41,13 @@ class TradeClient(object):
         : end_time: The end time of of requested candlestick/kline data. (optional)
         :return: The list of candlestick/kline data.
         """
+        channel = "/v1/fee/fee-rate/get"
         check_symbol(symbols)
 
         params = {
             "symbols": symbols
         }
-        return self.trade_client.get_fee_rate_service(params)
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def get_transact_fee_rate(self, symbols: str) -> list:
         """
@@ -53,8 +61,9 @@ class TradeClient(object):
         params = {
             "symbols": symbols
         }
+        channel = "/v2/reference/transact-fee-rate"
 
-        return self.trade_client.get_transact_fee_rate_service(params)
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def sub_order_update(self, symbols: str, callback, error_handler=None):
         """
@@ -75,11 +84,12 @@ class TradeClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-        }
+        def subscription(connection):
+            for val in symbol_list:
+                connection.send(orders_update_channel(val))
+                time.sleep(0.01)
 
-        self.trade_client_socket_sub.sub_order_update_v2_service(callback, error_handler, params)
+        self.trade_client_socket_sub.execute_subscribe_v2(subscription, callback, error_handler, is_trade=True)
 
     def req_order_list(self, symbol: str, account_id: int, callback, order_states: str,
                        order_types: str = None, start_date: str = None, end_date: str = None, from_id=None,
@@ -124,10 +134,14 @@ class TradeClient(object):
             "client-req-id": client_req_id
         }
 
-        self.trade_client_socket.req_order_list_service(callback, error_handler, params)
+        def subscription(connection):
+            connection.send(request_order_list_channel(symbol=symbol, account_id=account_id,
+                                                       states_str=order_states, client_req_id=client_req_id,
+                                                       more_key=params))
 
-    def req_order_detail(self, order_id: str, callback,
-                         client_req_id: str = None, error_handler=None):
+        self.trade_client_socket.execute_subscribe_v1(subscription, callback, error_handler, is_trade=True)
+
+    def req_order_detail(self, order_id: str, callback, client_req_id: str = None, error_handler=None):
         """
         Subscribe candlestick/kline event. If the candlestick/kline is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -147,14 +161,13 @@ class TradeClient(object):
         """
         check_should_not_none(order_id, "order_id")
         check_should_not_none(callback, "callback")
-        params = {
-            "order-id": order_id,
-            "cid": client_req_id,
-        }
 
-        self.trade_client_socket.req_order_detail_service(callback, error_handler, params)
+        def subscription(connection):
+            connection.send(request_order_detail_channel(order_id, client_req_id))
 
-    def get_order(self, order_id: 'int'):
+        self.trade_client_socket.execute_subscribe_v1(subscription, callback, error_handler, is_trade=True)
+
+    def get_order(self, order_id: int):
         """
         Get the details of an order.
 
@@ -166,7 +179,12 @@ class TradeClient(object):
         params = {
             "order_id": order_id,
         }
-        return self.trade_client.get_order_by_id_service(params)
+
+        def get_channel():
+            path = "/v1/order/orders/{}"
+            return path.format(order_id)
+
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, get_channel(), params)
 
     def get_order_by_client_order_id(self, client_order_id):
         check_should_not_none(client_order_id, "clientOrderId")
@@ -174,7 +192,8 @@ class TradeClient(object):
         params = {
             "clientOrderId": client_order_id,
         }
-        return self.trade_client.get_order_by_client_order_id_service(params)
+        channel = "/v1/order/orders/getClientOrder"
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def get_orders(self, symbol: str, order_state: OrderState, order_type: OrderType = None,
                    start_date: str = None, end_date: str = None, start_id: 'int' = None,
@@ -194,7 +213,9 @@ class TradeClient(object):
             "size": size,
             "direct": direct
         }
-        return self.trade_client.get_orders_service(params)
+        channel = "/v1/order/orders"
+
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def get_open_orders(self, symbol: str, account_id: 'int', side: 'OrderSide' = None,
                         size: 'int' = None, from_id=None, direct=None) -> list:
@@ -221,7 +242,9 @@ class TradeClient(object):
             "from": from_id,
             "direct": direct
         }
-        return self.trade_client.get_open_orders_service(params)
+        channel = "/v1/order/openOrders"
+
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def get_history_orders(self, symbol=None, start_time=None, end_time=None, size=None, direct=None) -> list:
         """
@@ -241,7 +264,9 @@ class TradeClient(object):
             "size": size,
             "direct": direct
         }
-        return self.trade_client.get_history_orders_service(params)
+        channel = "/v1/order/history"
+
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def get_match_result(self, symbol: str, order_type: OrderSide = None, start_date: str = None,
                          end_date: str = None,
@@ -275,7 +300,9 @@ class TradeClient(object):
             "from": from_id,
             "direct": direct
         }
-        return self.trade_client.get_match_results_service(params)
+        channel = "/v1/order/matchresults"
+
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def get_match_results_by_order_id(self, order_id: int) -> list:
         """
@@ -289,7 +316,12 @@ class TradeClient(object):
         params = {
             "order_id": order_id
         }
-        return self.trade_client.get_match_results_by_order_id_service(params)
+
+        def get_channel():
+            path = "/v1/order/orders/{}/matchresults"
+            return path.format(order_id)
+
+        return self.trade_client.request_process(HttpMethod.GET_SIGN, get_channel(), params)
 
     @staticmethod
     def order_source_desc(account_type):
@@ -354,7 +386,9 @@ class TradeClient(object):
 
         params = self.create_order_param_check(symbol, account_id, order_type, amount,
                                                price, source, client_order_id, stop_price, operator)
-        return self.trade_client.post_create_order_service(params)
+        channel = "/v1/order/orders/place"
+
+        return self.trade_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
     def create_spot_order(self, symbol: str, account_id: 'int', order_type: 'OrderType', amount: 'float',
                           price: 'float', client_order_id=None, stop_price=None,
@@ -390,7 +424,13 @@ class TradeClient(object):
         params = {
             "order_id": order_id
         }
-        return self.trade_client.post_cancel_order_service(params)
+        order_id = params["order_id"]
+
+        def get_channel():
+            path = "/v1/order/orders/{}/submitcancel"
+            return path.format(order_id)
+
+        return self.trade_client.request_process(HttpMethod.POST_SIGN, get_channel(), params)
 
     def cancel_orders(self, symbol, order_id_list):
         """
@@ -411,7 +451,8 @@ class TradeClient(object):
         params = {
             "order-ids": string_list
         }
-        return self.trade_client.post_batch_cancel_order_service(params)
+        channel = "/v1/order/orders/batchcancel"
+        return self.trade_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
     def cancel_open_orders(self, account_id, symbols: str = None, side=None, size=None):
         """
@@ -432,7 +473,9 @@ class TradeClient(object):
             "side": side,
             "size": size
         }
-        return self.trade_client.post_batch_cancel_open_order_service(params)
+        channel = "/v1/order/orders/batchCancelOpenOrders"
+
+        return self.trade_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
     def cancel_client_order(self, client_order_id) -> int:
         """
@@ -445,10 +488,12 @@ class TradeClient(object):
         params = {
             "client-order-id": client_order_id
         }
-        return self.trade_client.post_cancel_client_order_service(params)
+        channel = "/v1/order/orders/submitCancelClientOrder"
+
+        return self.trade_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
     def transfer_between_futures_and_pro(self, currency: str, amount: 'float',
-                                         transfer_type: 'TransferFuturesPro') -> int:
+                                         transfer_type: TransferFuturesPro) -> int:
         """
         Transfer Asset between Futures and Contract.
 
@@ -468,7 +513,9 @@ class TradeClient(object):
             "type": transfer_type
 
         }
-        return self.trade_client.post_transfer_futures_pro_service(params)
+        channel = "/v1/futures/transfer"
+
+        return self.trade_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
     def batch_create_order(self, order_config_list) -> int:
         """
@@ -506,7 +553,9 @@ class TradeClient(object):
 
             new_config_list.append(new_item)
 
-        return self.trade_client.post_batch_create_order_service(new_config_list)
+        channel = "/v1/order/batch-orders"
+
+        return self.trade_client.request_process_post_batch(HttpMethod.POST_SIGN, channel, new_config_list)
 
     def sub_trade_clearing(self, symbols: str, callback, error_handler=None):
         """
@@ -533,7 +582,9 @@ class TradeClient(object):
 
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-        }
-        return self.trade_client_socket_sub.sub_trade_clearing_v2_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(trade_clearing_channel(symbol))
+                time.sleep(0.01)
+
+        return self.trade_client_socket_sub.execute_subscribe_v2(subscription, callback, error_handler, is_trade=True)
