@@ -40,9 +40,10 @@ class AutoSaveDetail(SqliteTable):
                 self._save(now=self.save_time_unix)
 
     def _save(self, pop=None, now=None):
-        path_root = os.path.join(os.path.dirname(self.db_path), self.table_name, self.table_name)
+        path_root = os.path.join(os.path.dirname(self.db_path), self.table_name)
+        if not os.path.exists(path_root):
+            os.makedirs(path_root)
         name = self.table_name
-
         if self.save_freq in ('d', 'D', 'Day', 'day'):
             fmt = "%Y%m%d"
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
@@ -56,11 +57,17 @@ class AutoSaveDetail(SqliteTable):
         if self.save_key is not None:
             start, end = self.between_unix_ms(now)
             condition = '{key}>={start} and {key}<={end}'.format(key=self.save_key, start=start, end=end)
+            condition2 = '{key}<={end}'.format(key=self.save_key, end=end)
         else:
             condition = None
+            condition2 = None
+
+        path = '{}/{}-{}.csv'.format(path_root, name, self.save_time_unix.strftime(fmt))
+
+        self.to_csv(condition=condition, path=path)
+        if pop or self.save_with_clear:
+            self.delete(condition2)
 
-        path = '{}-{}-{}.csv'.format(path_root, name, self.save_time_unix.strftime(fmt))
-        self.to_csv(condition=condition, path=path, pop=pop or self.save_with_clear)
         self.save_time_unix = now
 
     def between_unix_ms(self, now):
@@ -92,7 +99,7 @@ class TradeDetail(AutoSaveDetail):
             db_path = os.path.abspath(
                 os.path.dirname(__file__)) + '/data/coin.db'
 
-        super(TradeDetail, self).__init__(db_path=db_path, table_name=table_name, *args, **kwargs)
+        super(TradeDetail, self).__init__(db_path=db_path, save_key='ts', table_name=table_name, *args, **kwargs)
         self.columns = ['trade_id', 'ts', 'direction', 'price', 'amount']
 
     def create(self):
@@ -117,6 +124,7 @@ class SymbolInfo(AutoSaveDetail):
         super(SymbolInfo, self).__init__(db_path=db_path,
                                          table_name=table_name,
                                          save_freq='y',
+                                         save_key='',
                                          save_with_clear=False,
                                          *args, **kwargs)
         self.columns = ['symbol', 'base_currency', 'quote_currency', 'price_precision', 'amount_precision',
@@ -171,7 +179,9 @@ class KlineDetail(AutoSaveDetail):
             db_path = os.path.abspath(
                 os.path.dirname(__file__)) + '/data/coin.db'
 
-        super(KlineDetail, self).__init__(db_path=db_path, table_name=table_name, *args, **kwargs)
+        super(KlineDetail, self).__init__(db_path=db_path,
+                                          save_key='id',
+                                          table_name=table_name, *args, **kwargs)
         self.columns = ['id', 'amount', 'count', 'open', 'close', 'low', 'high', 'vol']
 
     def create(self):
