@@ -14,17 +14,17 @@ class TradeUpdate:
         self.generic = GenericClient(api_key=api_key, secret_key=secret_key)
 
         self.symbolDB = SymbolInfo(db_path=db_path)
-        self.tradeDB = TradeDetail(db_path=db_path)
-        self.kline_1min = Kline1MinDetail(db_path=db_path)
-        self.kline_5min = Kline5MinDetail(db_path=db_path)
-        self.kline_15min = Kline15MinDetail(db_path=db_path)
-        self.kline_30min = Kline30MinDetail(db_path=db_path)
-        self.kline_60min = Kline60MinDetail(db_path=db_path)
-        self.kline_4hour = Kline4HourDetail(db_path=db_path)
-        self.kline_1day = Kline1DayDetail(db_path=db_path)
-        self.kline_1mon = Kline1MonDetail(db_path=db_path)
-        self.kline_1week = Kline1WeekDetail(db_path=db_path)
-        self.kline_1year = Kline1YearDetail(db_path=db_path)
+        self.tradeDB = TradeDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_1min = Kline1MinDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_5min = Kline5MinDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_15min = Kline15MinDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_30min = Kline30MinDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_60min = Kline60MinDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_4hour = Kline4HourDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_1day = Kline1DayDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_1mon = Kline1MonDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_1week = Kline1WeekDetail(db_path=db_path, conn=self.symbolDB.conn)
+        self.kline_1year = Kline1YearDetail(db_path=db_path, conn=self.symbolDB.conn)
 
         self.init()
 
@@ -95,17 +95,18 @@ class TradeUpdate:
         self.kline_1mon.auto_save()
         self.kline_1week.auto_save()
         self.kline_1year.auto_save()
+
     def _save(self):
-        self.tradeDB._sa()
-        self.kline_1min.auto_save()
-        self.kline_5min.auto_save()
-        self.kline_15min.auto_save()
-        self.kline_30min.auto_save()
-        self.kline_4hour.auto_save()
-        self.kline_1day.auto_save()
-        self.kline_1mon.auto_save()
-        self.kline_1week.auto_save()
-        self.kline_1year.auto_save()
+        self.tradeDB._save()
+        self.kline_1min._save()
+        self.kline_5min._save()
+        self.kline_15min._save()
+        self.kline_30min._save()
+        self.kline_4hour._save()
+        self.kline_1day._save()
+        self.kline_1mon._save()
+        self.kline_1week._save()
+        self.kline_1year._save()
 
     def insert_data(self, trade=True, kline=True):
         symbols = self.symbolDB.select("select symbol from {} where state ='online'".format(self.symbolDB.table_name))
@@ -139,13 +140,15 @@ class TradeUpdate:
             if t % 100 == 0:
                 self.insert_data(trade=True, kline=True)
                 self.auto_save()
-            elif t % 10 == 0:
-                self.auto_save()
             else:
                 self.insert_data(trade=True, kline=False)
                 t += 1
                 time.sleep(60)
 
+            if t % 10 == 0:
+                self._save()
+            print(t)
+
 
 update = TradeUpdate()
 update.run()
